RcKey

Struct RcKey 

pub struct RcKey(/* private fields */);
A remote-control key code (CEC or IR).

Implementations

Source

impl RcKey

pub const NUM0: Self

Digit 0.

pub const NUM1: Self

Digit 1.

pub const NUM2: Self

Digit 2.

pub const NUM3: Self

Digit 3.

pub const NUM4: Self

Digit 4.

pub const NUM5: Self

Digit 5.

pub const NUM6: Self

Digit 6.

pub const NUM7: Self

Digit 7.

pub const NUM8: Self

Digit 8.

pub const NUM9: Self

Digit 9.

pub const SELECT: Self

Confirm the highlighted item.

pub const BACK: Self

Go back one step.

pub const UP: Self

Navigate up.

pub const DOWN: Self

Navigate down.

pub const LEFT: Self

Navigate left.

pub const RIGHT: Self

Navigate right.

pub const MENU: Self

Open the main menu.

pub const CONTENT_MENU: Self

Open the content menu.

pub const CHANNEL_UP: Self

Next channel.

pub const CHANNEL_DOWN: Self

Previous channel.

pub const PLAY: Self

Start playback.

pub const PAUSE: Self

Pause playback.

pub const STOP: Self

Stop playback.

pub const RECORD: Self

Start recording.

pub const FAST_FORWARD: Self

Fast forward.

pub const REWIND: Self

Rewind.

pub const RED: Self

Red colour key.

pub const GREEN: Self

Green colour key.

pub const YELLOW: Self

Yellow colour key.

pub const BLUE: Self

Blue colour key.

pub const HELP: Self

Open help.

pub const INFORMATION: Self

Show information.

pub const TEXT: Self

Open teletext.

pub const GUIDE: Self

Open the programme guide.

pub const VIDEO_ON_DEMAND: Self

Open video on demand.

pub const PREVIOUS_CHANNEL: Self

Return to the previous channel.

pub const MODE_3D: Self

Toggle 3D mode.

pub const SUBTITLE: Self

Toggle subtitles.

pub const SOUND_SELECT: Self

Select an audio track.

pub const INPUT_SELECT: Self

Select an input.

pub const EJECT: Self

Eject the medium.

pub const NEXT_CHAPTER: Self

Next chapter.

pub const PREV_CHAPTER: Self

Previous chapter.

pub const INTERACTIVE: Self

Open interactive services.

pub const SEARCH: Self

Open search.

pub const SKY: Self

Sky home key.

pub const CUSTOM_CEC: Self

Base of the range carrying a raw CEC user-control code.

pub const CUSTOM_SKY: Self

Base of the range carrying a raw Sky key code.

pub const fn from_wire(value: u16) -> Self

Wraps a raw wire value, including one this library has no name for.

pub const fn to_wire(self) -> u16

Returns the raw wire value.