pub struct V2ipTestcardFlag(/* private fields */);Expand description
What a V2IP sink reports about its test card.
Implementations
Sourceimpl V2ipTestcardFlag
impl V2ipTestcardFlag
Sourcepub const PATTERN_PENDING: Self
pub const PATTERN_PENDING: Self
A pattern change has yet to reach the video processor.
Sourcepub const TONE_PENDING: Self
pub const TONE_PENDING: Self
A tone change has yet to reach the video processor.
Sourcepub const SYNC_PENDING: Self
pub const SYNC_PENDING: Self
A lip-sync change has yet to reach the video processor.