pub struct DeviceFeature(/* private fields */);Expand description
Capabilities a device reports in its hello frame.
Implementations
Sourceimpl DeviceFeature
impl DeviceFeature
Sourcepub const V2IP_SOURCE: Self
pub const V2IP_SOURCE: Self
Acts as a V2IP stream source.
Sourcepub const VIDEO_ROUTING: Self
pub const VIDEO_ROUTING: Self
Routes video.
Sourcepub const AUDIO_ROUTING: Self
pub const AUDIO_ROUTING: Self
Routes audio.
Sourcepub const VOLUME_CONTROL: Self
pub const VOLUME_CONTROL: Self
Controls volume.
Sourcepub const AUDIO_RETURN: Self
pub const AUDIO_RETURN: Self
Supports audio return.
Sourcepub const REMOTE_CONTROL: Self
pub const REMOTE_CONTROL: Self
Passes remote-control commands through.
Sourcepub const SETUP_COMPLETED: Self
pub const SETUP_COMPLETED: Self
Installer setup has been completed.
Sourcepub const MESH_MASTER: Self
pub const MESH_MASTER: Self
Is the master of its mesh.
Sourcepub const STATUS_NOTIFY: Self
pub const STATUS_NOTIFY: Self
Has a notification pending.
Sourcepub const STATUS_WARNING: Self
pub const STATUS_WARNING: Self
Has a warning pending.
Sourcepub const STATUS_ERROR: Self
pub const STATUS_ERROR: Self
Has an error pending.
Sourcepub const STATUS_REBOOT: Self
pub const STATUS_REBOOT: Self
Is about to reboot.
Sourcepub const MESH_MEMBER: Self
pub const MESH_MEMBER: Self
Is a member of a mesh.
Sourcepub const AUDIO_AMPLIFIER: Self
pub const AUDIO_AMPLIFIER: Self
Is an audio amplifier.
Sourcepub const STATUS_POWER_SAVE: Self
pub const STATUS_POWER_SAVE: Self
Is in power-save mode.
Sourcepub const MULTIVIEWER: Self
pub const MULTIVIEWER: Self
Is a multiviewer.
Sourcepub const STATUS_CRASHED: Self
pub const STATUS_CRASHED: Self
Has crashed since it last booted.
Sourcepub const VIDEO_WALL: Self
pub const VIDEO_WALL: Self
Supports video walls.
Sourcepub const CONFIG_INITIALISED: Self
pub const CONFIG_INITIALISED: Self
Initialises the configuration it broadcasts.
Firmware without this bit sends a device configuration built over uninitialised memory, so fields it did not mean to write carry junk.